from setuptools import setup

setup(name='distib_hawa',
      version='0.1',
      description='Gaussian distributions',
      packages=['distib_hawa'],
      author = 'Hawa Desai',
      author_email = 'techknowledge.cal@gmail.com',
      zip_safe=False)
